@@ -5,7 +5,10 @@ import platform
 import shlex
 import struct
 import subprocess
-import termios
+import sys
+
+if sys.platform != 'win32':
+    import termios
 
 log = logging.getLogger(__name__)
 
